Crate weighted_levenshtein

weighted_levenshtein

A generic implementation of Levenshtein distance that supports arbitrary weighting of edit operations.

Optional Features

  • default-weight (requires feature(specialization), so nightly Rust): Provides a default implementation of EditWeight for any PartialEq type. All operations have weight 1.

Traits

  • Trait for types that have custom costs for addition/removal and substitution.

Functions

  • Compute the Levenshtein distance between two sequences.